==> lxqt-panel-1.0.0.tar.xz: lxqt-panel-1.0.0/plugin-taskbar/translations/taskbar_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>LXQtTaskBar</name>
    <message>
        <location filename="../lxqttaskbar.cpp" line="681"/>
        <source>Activate task %1</source>
        <translation>Taak %1 activeren</translation>
    </message>
</context>
<context>
    <name>LXQtTaskButton</name>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="677"/>
        <source>Application</source>
        <translation>Programma</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="711"/>
        <source>To &amp;Desktop</source>
        <translation>Naar bureaubla&amp;d</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="713"/>
        <source>&amp;All Desktops</source>
        <translation>&amp;Alle werkbladen</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="721"/>
        <source>Desktop &amp;%1</source>
        <translation>Werkblad &amp;%1</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="728"/>
        <source>&amp;To Current Desktop</source>
        <translation>&amp;Naar huidig werkblad</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="737"/>
        <source>Move To &amp;Next Monitor</source>
        <translation>Verplaatsen naar volge&amp;nd beeldscherm</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="740"/>
        <source>Move To &amp;Previous Monitor</source>
        <translation>Ver&amp;plaatsen naar vorig beeldscherm</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="744"/>
        <source>&amp;Move</source>
        <translation>&amp;Verplaatsen</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="747"/>
        <source>Resi&amp;ze</source>
        <translation>Grootte aanpas&amp;sen</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="754"/>
        <source>Ma&amp;ximize</source>
        <translation>Ma&amp;ximaliseren</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="761"/>
        <source>Maximize vertically</source>
        <translation>Verticaal maximaliseren</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="766"/>
        <source>Maximize horizontally</source>
        <translation>Horizontaal maximaliseren</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="772"/>
        <source>&amp;Restore</source>
        <translation>He&amp;rstellen</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="776"/>
        <source>Mi&amp;nimize</source>
        <translation>Mi&amp;nimaliseren</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="782"/>
        <source>Roll down</source>
        <translation>Uitrollen</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="788"/>
        <source>Roll up</source>
        <translation>Oprollen</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="796"/>
        <source>&amp;Layer</source>
        <translation>&amp;Laag</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="798"/>
        <source>Always on &amp;top</source>
        <translation>Al&amp;tijd bovenaan</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="804"/>
        <source>&amp;Normal</source>
        <translation>&amp;Normaal</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="810"/>
        <source>Always on &amp;bottom</source>
        <translation>Altijd &amp;onderaan</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="818"/>
        <source>&amp;Close</source>
        <translation>&amp;Sluiten</translation>
    </message>
</context>
<context>
    <name>LXQtTaskGroup</name>
    <message>
        <location filename="../lxqttaskgroup.cpp" line="81"/>
        <source>Group</source>
        <translation>Groep</translation>
    </message>
    <message>
        <location filename="../lxqttaskgroup.cpp" line="83"/>
        <source>Close group</source>
        <translation>Groep sluiten</translation>
    </message>
</context>
<context>
    <name>LXQtTaskbarConfiguration</name>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="14"/>
        <source>Task Manager Settings</source>
        <translation>Taakbalk-instellingen</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Algemeen</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="43"/>
        <source>Show only windows from desktop</source>
        <translation>Alleen vensters van huidig werkblad tonen</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="55"/>
        <source>Show only windows from &amp;panel&apos;s screen</source>
        <translation>Alleen vensters van scherm van &amp;paneel tonen</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="62"/>
        <source>Show only minimized windows</source>
        <translation>Alleen geminimaliseerde vensters tonen</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="69"/>
        <source>Raise minimized windows on current desktop</source>
        <translation>Geminimaliseerde vensters herstellen op huidig werkblad</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="49"/>
        <source>Cycle windows on wheel scrolling</source>
        <translation>Tussen vensters schakelen door te scrollen met muiswiel</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="143"/>
        <source>Window &amp;grouping</source>
        <translation>Venster&amp;groepering</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="152"/>
        <source>Show popup on mouse hover</source>
        <translation>Pop-upvenster tonen bij aanwijzen met cursor</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="169"/>
        <source>Appearance</source>
        <translation>Vormgeving</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="188"/>
        <source>Maximum button width</source>
        <translation>Maximale knopbreedte</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="125"/>
        <location filename="../lxqttaskbarconfiguration.ui" line="201"/>
        <location filename="../lxqttaskbarconfiguration.ui" line="227"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="86"/>
        <source>Mouse Wheel</source>
        <translation>Muiswiel</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="112"/>
        <source>Wheel Delta Threshold</source>
        <translation>Drempelwaarde wieldelta</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="162"/>
        <source>Put buttons of the same class next to each other</source>
        <translation>Gelijkaardige knoppen naast elkaar tonen</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="214"/>
        <source>Maximum button height</source>
        <translation>Maximale knophoogte</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="247"/>
        <source>Use icons by WindowClass, if available</source>
        <translation>Pictogrammen van vensterklasse gebruiken (indien beschikbaar)</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="240"/>
        <source>Auto&amp;rotate buttons when the panel is vertical</source>
        <translation>Knoppen automatisch d&amp;raaien als de paneel verticaal is</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="178"/>
        <source>Button style</source>
        <translation>Knopstijl</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="76"/>
        <source>Close on middle-click</source>
        <translation>Sluiten met middelste muisknop</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="44"/>
        <source>Icon and text</source>
        <translation>Pictogram en tekst</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="45"/>
        <source>Only icon</source>
        <translation>Alleen pictogram</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="46"/>
        <source>Only text</source>
        <translation>Alleen tekst</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="48"/>
        <source>Disabled</source>
        <translation>Uitgeschakeld</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="50"/>
        <source>Scroll up to raise, down to minimize</source>
        <translation>Scroll omhoog om te herstellen en naar beneden om te minimaliseren</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="51"/>
        <source>Scroll up to minimize, down to raise</source>
        <translation>Scroll omhoog om te minimaliseren en naar beneden om te herstellen</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="52"/>
        <source>Scroll up to move to next desktop, down to previous</source>
        <translation>Scroll omhoog om naar het volgende werkblad te gaan en omlaag voor het vorige werkblad</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="53"/>
        <source>Scroll up to move to previous desktop, down to next</source>
        <translation>Scroll omhoog om naar het vorige werkblad te gaan en omlaag voor het volgende werkblad</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="55"/>
        <source>Current</source>
        <translation>Huidig</translation>
    </message>
</context>
</TS>

==> lxqt-panel-2.0.0.tar.xz: lxqt-panel-2.0.0/plugin-taskbar/translations/taskbar_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>LXQtTaskBar</name>
    <message>
        <location filename="../lxqttaskbar.cpp" line="681"/>
        <source>Activate task %1</source>
        <translation>%1 activeren</translation>
    </message>
</context>
<context>
    <name>LXQtTaskButton</name>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="674"/>
        <source>Application</source>
        <translation>Programma</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="708"/>
        <source>To &amp;Desktop</source>
        <translation>Naar bureaubla&amp;d</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="710"/>
        <source>&amp;All Desktops</source>
        <translation>&amp;Alle werkbladen</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="720"/>
        <source>Desktop &amp;%1</source>
        <translation>Werkblad &amp;%1</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="730"/>
        <source>&amp;To Current Desktop</source>
        <translation>&amp;Naar huidig werkblad</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="739"/>
        <source>Move To N&amp;ext Monitor</source>
        <translation>Verplaatsen naar volge&amp;nd beeldscherm</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="742"/>
        <source>Move To &amp;Previous Monitor</source>
        <translation>Ver&amp;plaatsen naar vorig beeldscherm</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="746"/>
        <source>&amp;Move</source>
        <translation>&amp;Verplaatsen</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="749"/>
        <source>Resi&amp;ze</source>
        <translation>Grootte aanpas&amp;sen</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="756"/>
        <source>Ma&amp;ximize</source>
        <translation>Ma&amp;ximaliseren</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="763"/>
        <source>Maximize vertically</source>
        <translation>Verticaal maximaliseren</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="768"/>
        <source>Maximize horizontally</source>
        <translation>Horizontaal maximaliseren</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="774"/>
        <source>&amp;Restore</source>
        <translation>He&amp;rstellen</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="778"/>
        <source>Mi&amp;nimize</source>
        <translation>Mi&amp;nimaliseren</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="784"/>
        <source>Roll down</source>
        <translation>Uitrollen</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="790"/>
        <source>Roll up</source>
        <translation>Oprollen</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="798"/>
        <source>&amp;Layer</source>
        <translation>&amp;Laag</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="800"/>
        <source>Always on &amp;top</source>
        <translation>Al&amp;tijd bovenaan</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="806"/>
        <source>&amp;Normal</source>
        <translation>&amp;Normaal</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="812"/>
        <source>Always on &amp;bottom</source>
        <translation>Altijd &amp;onderaan</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="820"/>
        <source>&amp;Close</source>
        <translation>&amp;Sluiten</translation>
    </message>
</context>
<context>
    <name>LXQtTaskGroup</name>
    <message>
        <location filename="../lxqttaskgroup.cpp" line="82"/>
        <source>Group</source>
        <translation>Groep</translation>
    </message>
    <message>
        <location filename="../lxqttaskgroup.cpp" line="84"/>
        <source>Close group</source>
        <translation>Groep sluiten</translation>
    </message>
</context>
<context>
    <name>LXQtTaskbarConfiguration</name>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="14"/>
        <source>Task Manager Settings</source>
        <translation>Taakbalkinstellingen</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Algemeen</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="43"/>
        <source>Show only windows from desktop</source>
        <translation>Alleen vensters van huidig werkblad tonen</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="55"/>
        <source>Show only windows from &amp;panel&apos;s screen</source>
        <translation>Alleen vensters van scherm met &amp;paneel tonen</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="62"/>
        <source>Show only minimized windows</source>
        <translation>Alleen geminimaliseerde vensters tonen</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="69"/>
        <source>Raise minimized windows on current desktop</source>
        <translation>Geminimaliseerde vensters herstellen op huidig werkblad</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="49"/>
        <source>Cycle windows on wheel scrolling</source>
        <translation>Tussen vensters schakelen door te scrollen met muiswiel</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="143"/>
        <source>Window &amp;grouping</source>
        <translation>Venster&amp;groepering</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="152"/>
        <source>Show popup on mouse hover</source>
        <translation>Pop-upvenster tonen na aanwijzen met cursor</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="169"/>
        <source>Appearance</source>
        <translation>Vormgeving</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="188"/>
        <source>Maximum button width</source>
        <translation>Maximale knopbreedte</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="125"/>
        <location filename="../lxqttaskbarconfiguration.ui" line="201"/>
        <location filename="../lxqttaskbarconfiguration.ui" line="227"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="86"/>
        <source>Mouse Wheel</source>
        <translation>Muiswiel</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="112"/>
        <source>Wheel Delta Threshold</source>
        <translation>Drempelwaarde wieldelta</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="162"/>
        <source>Put buttons of the same class next to each other</source>
        <translation>Gelijkaardige knoppen naast elkaar tonen</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="214"/>
        <source>Maximum button height</source>
        <translation>Maximale knophoogte</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="247"/>
        <source>Use icons by WindowClass, if available</source>
        <translation>Pictogrammen van vensterklasse gebruiken (indien beschikbaar)</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="240"/>
        <source>Auto&amp;rotate buttons when the panel is vertical</source>
        <translation>Knoppen automatisch d&amp;raaien indien paneel verticaal is</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="178"/>
        <source>Button style</source>
        <translation>Knopstijl</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="76"/>
        <source>Close on middle-click</source>
        <translation>Sluiten met middelste muisknop</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="44"/>
        <source>Icon and text</source>
        <translation>Pictogram en tekst</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="45"/>
        <source>Only icon</source>
        <translation>Alleen pictogram</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="46"/>
        <source>Only text</source>
        <translation>Alleen tekst</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="48"/>
        <source>Disabled</source>
        <translation>Uitgeschakeld</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="50"/>
        <source>Scroll up to raise, down to minimize</source>
        <translation>Scrol omhoog om te herstellen en naar beneden om te minimaliseren</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="51"/>
        <source>Scroll up to minimize, down to raise</source>
        <translation>Scrol omhoog om te minimaliseren en naar beneden om te herstellen</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="52"/>
        <source>Scroll up to move to next desktop, down to previous</source>
        <translation>Scrol omhoog voor het volgende werkblad en omlaag voor het vorige</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="53"/>
        <source>Scroll up to move to previous desktop, down to next</source>
        <translation>Scrol omhoog voor het vorige werkblad en omlaag voor het volgende</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="55"/>
        <source>Current</source>
        <translation>Huidig</translation>
    </message>
</context>
</TS>
